#!/bin/sh

HOME=`pwd`
RC=0
log_flag=0
diskspacelimit=30
smode=0
fmode=0
ipmode=0
dumpmode=0
lockFile="/tmp/HostinfoAnalyzeTool-aix.lock"

RUN_CONFLICT_EXITCODE=200
NO_ENOUGH_SPACE_EXITCODE=201

lockShell()
{
    local thepid=""
    local ret=""

    if [ "$1" = "" ]
    then
        echo "need lock file param"
        exit 1
    fi

    if [ -f "${1}" ]
    then
        thepid=`cat "${1}"`
        if [ "${thepid}" != "" ]
        then
            ret=`ps -ef |awk '{print $2}'| grep -c "^[[:blank:]]*${thepid}[[:blank:]]*$"`
            if [ ${ret} -eq 1 ]
            then
                echo "this shell is already running, exit."
                exit ${RUN_CONFLICT_EXITCODE}
            fi
        fi
    fi

    echo $$ > "${1}"
    chmod go+w "${1}"
    return 0
}

unlockShell()
{
    if [ "$1" = "" ]
    then
        echo "need lock file param"
        return 1
    fi

    if [ -f "${1}" ]
    then
        rm -f "${1}"
    fi

    return 0
}

host_exit()
{
    unlockShell "${lockFile}"
    exit "$1"
}





TMP_OS_V=`uname -s`
if [ "${TMP_OS_V}" != "AIX" ]; then
    echo "\033[1;31m    ERROR : Only support AIX! The OS is ${TMP_OS_V}\033[0m"
    exit 1
fi

lockShell "${lockFile}"

if [ ! -f ${HOME}/HostInfoTools-aix.main ]
then
    echo "\033[1;31mUnable to source HostInfoTools-aix.main\033[0m"
    host_exit 1
fi

. ${HOME}/HostInfoTools-aix.main

trap "clear; echo \"Interrupt Caught....exiting\"; cleanup; exit 1" 1 2 3 15

startup

freeSpace=`df -m ${HOME} | sed -n '2p' | awk '{print $3}'`
if [ ${freeSpace} -lt ${diskspacelimit} ]
then
    echo "\033[1;31m    ERROR : more disk free space need, exit!\033[0m"
    host_exit ${NO_ENOUGH_SPACE_EXITCODE}
fi


SAVE_CMDLINE=$*
while [ $# -gt 0 ]
do
    SHFT=2
    case $1 in
        -h)        usage;host_exit 0;;
        -NEWDir)    OUTPUT_DIR=$2;;
        -e)        log_flag=$2;;
        -s)        smode=1;SHFT=1;;
        -f)        fmode=1;SHFT=1;;
		-d)        dumpmode=1;SHFT=1;;
        *)        echo "\033[1;31mUnknown command line option: ${1}\033[0m";host_exit 0;;
    esac
    shift ${SHFT}
done

   
if [ ${smode} = 0 ]
then
    echo "WARNING: Do you want to collect dump file? If yes,the dump file may be involved in the collection of private data or suspected by customer,please confirm with the customer before the collection."
	echo -n "<Y|N>:"
	while read ret
    do
        case ${ret} in
        Y|y)   echo "continue... "
               dumpmode=1;
			   break;;
        N|n)   dumpmode=0;
               break;;
        *) echo "Please answer (Y/y) or (N/n) : \c";;
        esac
    done
	
fi

echo "NOTE: we will collect some information as follows:
    1) log of UltraPath
    2) package information of UltraPath
    3) informaton of disk/lun managed by UltraPath
    4) configure file of UltraPath
    5) log of system
    6) information of HBA
    7) information of file system
    8) system environment variable
    9) information of ODM database in AIX system, include PdDv, PdAt, CuPathAt and PdPathAt
    10) information of host including IP, version of system, Kernel Type, and process state"

if [ ${smode} = 0 ]
then
    echo "do you want to collect these infomations(y/n)?:"

    while read ret
    do
        case ${ret} in
        Y|y)   echo "continue... "
                    break;;
        N|n)   echo "exit "
                host_exit 1;;
        *) echo "Please answer (Y/y) or (N/n) : \c";;
        esac
    done
fi

if [ ! -d ${UP_TMP} ]
then
    mkdir ${UP_TMP}
fi

if [ -z "${OUTPUT_DIR}" ]
then
    OUTPUT_DIR=${HOME}
fi

export OUTPUT_DIR

if [ ! -d ${OUTPUT_DIR} ]
then
    mkdir ${OUTPUT_DIR}
fi

modules

printf "\nCollectScript version: ${VERSION}" | tee -a ${RPT}
printf "\nCommand line options: ${SAVE_CMDLINE}" | tee -a ${RPT}
printf "\nModules to be processed: ${COMMAND_LIST}\n" | tee -a ${RPT}

printf "file directory is: ${SCRIPTS}\n"
START_TIME="`date +%d/%m/%y` - `date +%H:%M:%S`"

printf "start run time is: ${START_TIME}\n"

for file in `echo ${COMMAND_LIST}`
do
    SCRIPTNAME=${file}
    export SCRIPTNAME

    TIME="`date +%d/%m/%y` - `date +%H:%M:%S`"
    printf "\n\nModule ${file} started at : ${TIME}" >> ${RPT}
    printf "\nfile directory is: ${SCRIPTS}/${file}.sh\n"

    if [ ! -x ${SCRIPTS}/${file}.sh ]
    then
        chmod +x ${SCRIPTS}/${file}.sh
    fi

    if [ -x ${SCRIPTS}/${file}.sh ]
    then
        checking_fs "${smode}"
        printf "\nRunning module - ${file}.sh" >> ${ERR_RPT}
        sh ${SCRIPTS}/${file}.sh
    else
        printf "\nModule ${file} not found.  Skipping ...\n" | tee -a ${RPT}
    fi
done

log_row=100

if [ ${log_flag} -ne 0 ]
then
    log_row=${log_flag}
fi

export log_row
printf "\nGet last ${log_row} row of the system log ...\n" | tee -a ${RPT}
errpt -a |tail -${log_row} >> ${SYS_LOG}

if [ `lslpp -l | grep cluster 2>&1|wc -l` -ne 0 ]
then
    printf "\nGet culster information ...\n" | tee -a ${RPT}
	snap -e >> ${RPT}
	if [ $? -ne 0 ]
	then 
	    host_exit 1
    fi
	
	if [ -f /tmp/ibmsupt/snap.pax.Z ]
	then
	    SANPPAXSIZE=`du -k /tmp/ibmsupt/snap.pax.Z | awk '{print $1}'`
		if [ "$UNIXSIZE" != "" ]
		then 
		    CheckOutDirFreeSpace ${UP_TMP} ${SANPPAXSIZE}
	        cp -p /tmp/ibmsupt/snap.pax.Z ${UP_TMP} >> ${RPT}
	    fi
	fi
fi

if [ ${dumpmode} = 1 ]
then
	printf "\nGet dump information ...\n" | tee -a ${RPT}
	DUMPSAVEDIR=${UP_TMP}/dump
	if [ ! -d ${DUMPSAVEDIR} ]
	then 
	    mkdir -p ${DUMPSAVEDIR}
    fi
	
	snap -ac >> ${RPT}
	if [ $? -ne 0 ]
	then 
	    host_exit 1
    fi
	
	if [ -f /tmp/ibmsupt/dump/dump.Z ]
	then
	    DUMPSIZE=`du -k /tmp/ibmsupt/dump/dump.Z | awk '{print $1}'`
		if [ "$DUMPSIZE" != "" ]
		then
		    CheckOutDirFreeSpace ${DUMPSAVEDIR} ${DUMPSIZE}
	        cp -p /tmp/ibmsupt/dump/dump.Z ${DUMPSAVEDIR} >> ${RPT}
        fi
    elif [ -f /tmp/ibmsupt/dump/dump.BZ ]
	then
        DUMPSIZE=`du -k /tmp/ibmsupt/dump/dump.BZ |awk '{print $1}'`
		if [ "$DUMPSIZE" != "" ]
		then
		    CheckOutDirFreeSpace ${DUMPSAVEDIR} ${DUMPSIZE}
	        cp -p /tmp/ibmsupt/dump/dump.BZ ${DUMPSAVEDIR} >> ${RPT}
	    fi
	fi
    
    if [ -f /tmp/ibmsupt/dump/unix.Z ]
	then
	    UNIXSIZE=`du -k /tmp/ibmsupt/dump/unix.Z | awk '{print $1}'`
		if [ "$UNIXSIZE" != "" ]
		then 
		    CheckOutDirFreeSpace ${DUMPSAVEDIR} ${UNIXSIZE}
	        cp -p /tmp/ibmsupt/dump/unix.Z ${DUMPSAVEDIR} >> ${RPT}
	    fi
	fi
	
	if [ -f /tmp/ibmsupt/snap.pax.Z ]
	then
	    SANPPAXSIZE=`du -k /tmp/ibmsupt/snap.pax.Z | awk '{print $1}'`
		if [ "$UNIXSIZE" != "" ]
		then 
		    CheckOutDirFreeSpace ${DUMPSAVEDIR} ${SANPPAXSIZE}
	        cp -p /tmp/ibmsupt/snap.pax.Z ${DUMPSAVEDIR} >> ${RPT}
	    fi
	fi
		
fi



TAR_FILE_NAME=Aix-Info.tar

printf "\n\nData Collection Started at : ${START_TIME}" >> ${RPT}
printf "\n\nData Collection Finished at : ${END_TIME}" >> ${RPT}
printf "\n\nOutput Filename is : ${TAR_FILE_NAME}.${TAR_SUFFIX}\n" >> ${RPT}

outputs_index

printf "\n\nCreating and compressing Tar File ${TAR_FILE_NAME}"
cd ${UP_TMP}
tar chf ${OUTPUT_DIR}/${TAR_FILE_NAME} * & >/dev/null 2>&1
PID=$!
while [ `ps -p ${PID} | wc -l` -eq 2 ]
do
    sleep 1
    printf "."
done

cd ${HOME}

printf "\n\nCreating and compressing gz File ${TAR_FILE_NAME}.gz"
${COMPRESS} ${OUTPUT_DIR}/${TAR_FILE_NAME} & > /dev/null 2>&1
PID=$!
while [ `ps -p ${PID} | wc -l` -eq 2 ]
do
    sleep 1
    printf "."
done

printf "\n"
echo "Please submit this file to UltraPath for Analysis. Thank you!"
echo

cleanup

host_exit ${RC}
